@@ -3,7 +3,7 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|1.4.2|
+|''Version''|1.4.4|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
@@ -210,10 +210,9 @@ adaptor.prototype.getTiddler = function(title, context, userParams, callback) {
 	context.tiddler.fields["server.type"] = adaptor.serverType;
 	context.tiddler.fields["server.host"] = AdaptorBase.minHostName(context.host);
 	context.tiddler.fields["server.workspace"] = context.workspace;
-	var serverTitle = context.tiddler.fields["server.title"] || title;
 	var workspace = adaptor.resolveWorkspace(context.workspace);
 	var uri = uriTemplate.format([context.host, workspace.type + "s",
-		adaptor.normalizeTitle(workspace.name), adaptor.normalizeTitle(serverTitle),
+		adaptor.normalizeTitle(workspace.name), adaptor.normalizeTitle(title),
 		context.revision]);
 	var req = httpReq("GET", uri, adaptor.getTiddlerCallback, context,
 		merge({ accept: adaptor.mimeType }, context.headers), null, null, null, null, true);
@@ -424,7 +423,10 @@ adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback
 		} else if(context.workspace.substring(0, 4) != "bags") { // NB: target workspace must be a bag
 			context.workspace = "bags/" + rev.bag;
 		}
-		var subCallback = function(context, userparams) {
+		var subCallback = function(context, userParams) {
+			if(!context.status) {
+				return callback(context, userParams);
+			}
 			context.adaptor.getTiddler(newTiddler.title, context, userParams, _deleteTiddler);
 		};
 		return self.putTiddlerChronicle(revisions, context, context.userParams, subCallback);
@@ -433,6 +435,7 @@ adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback
 		if(!context.status) {
 			return callback(context, userParams);
 		}
+		$.extend(true, newTiddler, context.tiddler);
 		context.callback = null;
 		return self.deleteTiddler(oldTiddler, context, context.userParams, callback);
 	};
